/*
Copyright © 2024 filifa

This program is free software: you can redistribute it and/or modify it under
the terms of the GNU General Public License as published by the Free Software
Foundation, either version 3 of the License, or (at your option) any later
version.

This program is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
PARTICULAR PURPOSE. See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with
this program. If not, see <http://www.gnu.org/licenses/>.
*/
package cmd

import (
	"strings"

	"scm.dairydemon.net/filifa/mlblive/cmd/internal/statsapi"
)

var leagueIDs = map[string]statsapi.LeagueID{
	"al":  statsapi.AL,
	"nl":  statsapi.NL,
	"nn2": statsapi.NN2,
	"nnl": statsapi.NNL,
	"ewl": statsapi.EWL,
	"nal": statsapi.NAL,
	"ecl": statsapi.ECL,
	"anl": statsapi.ANL,
	"nsl": statsapi.NSL,
	"aa":  statsapi.AA,
	"pl":  statsapi.PL,
	"ua":  statsapi.UA,
	"fl":  statsapi.FL,
}

type leagueAbbr string

func (t *leagueAbbr) String() string {
	return string(*t)
}

func (t *leagueAbbr) Set(v string) error {
	v = strings.ToLower(v)

	err := validateFlag(v, leagueIDs)
	if err != nil {
		return err
	}

	*t = leagueAbbr(v)
	return nil
}

func (t *leagueAbbr) Type() string {
	return "leagueAbbr"
}
